#include <iostream>
#include <vector>
#include <cassert>

using namespace std;

struct point{
  double x;
  double y;
};

struct line{
  point start;
  point end;
};


int Cross(point p1, point p2){
  return p1.x*p2.y-p2.x*p1.y;
}

int Direction(point pi, point pj, point pk){
  point first;
  first.x = pk.x-pi.x;
  first.y = pk.y-pi.y;
  point second;
  second.x = pj.x-pi.x;
  second.y = pj.y-pi.y;
  return Cross(first,second);
}


bool On_Segment(point pi, point pj, point pk){
  if(min(pi.x,pj.x) <= pk.x && pk.x <= max(pi.x,pj.x) &&
     min(pi.y,pj.y) <= pk.y && pk.y <= max(pi.y,pj.y))
    return true;
  else return false;
}

bool Intersects(line l1, line l2){
  point p1 = l1.start;
  point p2 = l1.end;
  point p3 = l2.start;
  point p4 = l2.end;

  int d1 = Direction(p3,p4,p1);
  int d2 = Direction(p3,p4,p2);
  int d3 = Direction(p1,p2,p3);
  int d4 = Direction(p1,p2,p4);


  if(((d1>0 && d2<0) || (d1<0 && d2>0)))
    if((d3>0 && d4<0) || (d3<0 && d4>0))
    return true;


  // make sure input is valid
  if(d1 == 0)
    assert (!On_Segment(p3,p4,p1));

  if(d2 == 0)
    assert (!On_Segment(p3,p4,p2));
  if(d3 == 0)
    assert(!On_Segment(p1,p2,p3));
  if(d4 == 0)
    assert(!On_Segment(p1,p2,p4));
    
  
  return false;
}


int main(){
   int cur_case = 1;
   int n;
   cin >> n;
   while(n > 0){
     vector<line> obstacles(n);
     for(int i = 0; i < n; i++){
       cin >> obstacles[i].start.x;
       cin >> obstacles[i].start.y;
       cin >> obstacles[i].end.x;
       cin >> obstacles[i].end.y;
     }
     int c;
     cin >> c;
     vector<point> children(c);
     for(int i = 0; i < c; i++){
       cin >> children[i].x;
       cin >> children[i].y;
     }
     
     point lady_pos;
     int p;
     cin >> p;
     for(int i = 0; i < p; i++){
       cout << "Case " << cur_case << ", Position " << i+1 << ": ";
       line LOS;
       cin >> lady_pos.x;
       cin >> lady_pos.y;
       LOS.start = lady_pos;
       int num_seen = 0;
       for(int j = 0; j < c; j++){
	 LOS.end=children[j];
	 bool hit_wall = false;
	 int k = 0;
	 while(k < n && !hit_wall){
	   if(Intersects(LOS, obstacles[k]))
	     hit_wall = true;
	   k++;
	 }
	 if(!hit_wall)
	   num_seen++;
       }
       
       cout << "Children seen: " << num_seen << endl;
      
     }
     cur_case++;
     cout << endl;
     cin >> n;
     
   }
   return 0;
}
